@@ -187,10 +187,10 @@ class fAPN_GUI(hildon.Program):
 	def create_about_dialog(self):
 		dialog = gtk.AboutDialog()                                                 
 		dialog.set_name("fAPN")
-		#fmms_logo = gtk.gdk.pixbuf_new_from_file("/opt/fmms/fmms.png")
-		#dialog.set_logo(fmms_logo)                                   
+		fapn_logo = gtk.gdk.pixbuf_new_from_file("/opt/fapn/fapn_64px.png")
+		dialog.set_logo(fapn_logo)                                   
 		dialog.set_comments('Adding GPRS APN in Fremantle')
-		dialog.set_version("0.1")                                                
+		dialog.set_version("0.2")                                                
 		dialog.set_copyright("By Nick Leppänen Larsson (aka frals)")                    
 		dialog.set_website("http://www.frals.se/")                                  
 		dialog.connect("response", lambda d, r: d.destroy())                      
